MYSQL_CONFIG={
        'host':'localhost',
        'user':'monitor_user',
        'password':'YOUR_PASSWORD_HEAR',
        'database':'server_monitor',
        'charset':'utf8',
        'autocommit':True
}

SERVER_PORT=6000
SERVER_HOST='0.0.0.0'
